@@ -37,7 +37,7 @@ class PartMan : public QObject
         Label,
         UseFor,
         Encrypt,
-        Type,
+        Format,
         Options
     };
     MProcess &proc;
@@ -45,20 +45,23 @@ class PartMan : public QObject
     Ui::MeInstall &gui;
     QWidget *master;
     QMap<QString, QTreeWidgetItem *> mounts;
-    QList<QTreeWidgetItem *> swaps;
     QStringList listToUnmount;
     void setup();
+    void clearLayout(QTreeWidgetItem *drvit);
     inline QTreeWidgetItem *addItem(QTreeWidgetItem *parent, int defaultMB,
         const QString &defaultUse, bool crypto);
     void setupItem(QTreeWidgetItem *twit, const BlockDeviceInfo *bdinfo,
         int defaultMB = 0, const QString &defaultUse = QString());
     void labelParts(QTreeWidgetItem *drive);
     static QString translateUse(const QString &alias);
+    static QString describeUse(const QString &use);
     void clearPartitionTables(const QString &dev);
     bool formatLinuxPartition(const QString &dev, const QString &type, bool chkBadBlocks, const QString &label);
     void setEncryptChecks(const QString &use,
         enum Qt::CheckState state, QTreeWidgetItem *exclude);
     bool calculatePartBD();
+    inline void drvitMarkLayout(QTreeWidgetItem *drvit, const bool old);
+    inline bool twitIsOldLayout(const QTreeWidgetItem *twit, const bool chkUp=true) const;
     inline long long twitSize(QTreeWidgetItem *twit, bool bytes=false);
     inline bool twitWillFormat(QTreeWidgetItem *twit);
     inline QString twitUseFor(QTreeWidgetItem *twit);
